<!DOCTYPE html>
<html><head>

    <title>Code For Life - there has been an error</title>


    <link rel="stylesheet" type="text/css" href="/static/portal/css/styles.css">
    <link rel="stylesheet" type="text/css" href="/static/portal/css/list.css">
    <link rel="stylesheet" type="text/css" href="/static/portal/css/tables.css">

</head>

<body>


<div id="contentWrapper">

    <div class="topBar">
        <div class="content">
            <a href="/" class="logo">
                <span></span>
                <h1>Code for Life</h1>
            </a>
            <ul class="topNav">
                <li><b>[ <a href="/teach/">TEACH</a> ]</b></li>
                <li><a href="/play/">PLAY</a></li>

                <li>Mr Einstein | <a href="/logout/">LOGOUT</a></li>

            </ul>
        </div>
    </div>



    <div class="subnavBar">
        <div class="subnav">
            <ul>


                <li><b><a href="/teach/home/">Dashboard</a></b></li>
                <li><a href="/teach/classes/">Classes</a></li>
                <li><a href="/teach/account/">Account</a></li>
                <li><a href="/teach/school/manage/">School | Club</a></li>

            </ul>
        </div>
    </div>





    <div class="content">




        <div class="topPadding"></div>

        <h2>
            Oh dear!  Something's gone wrong.
        </h2>
        <p>
            Please go back and try again.
        </p>


    </div>


    <div class="push"></div>
</div>



<div class="footer">
    <ul>
        <li><a href="/about/">About us</a></li>
        <li><a href="/contact/">Contact Us</a></li>
        <li><a href="/terms/">Terms of use</a></li>
        <li><a href="/help/">Help &amp; Support</a></li>
        <li><a href="http://www.ocadotechnology.com/">Ocado Technology</a> &copy; 2016</li>
    </ul>
</div>




</body></html>
